==> platform-client-v2-176.0.0-sources.jar: com/mypurecloud/sdk/v2/model/BuAgentScheduleActivity.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.deser.std.StdDeserializer;
import java.util.Objects;
import java.util.ArrayList;
import java.io.IOException;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.Date;

import java.io.Serializable;
/**
 * BuAgentScheduleActivity
 */

public class BuAgentScheduleActivity  implements Serializable {
  
  private Date startDate = null;
  private Integer lengthMinutes = null;
  private String description = null;
  private String activityCodeId = null;
  private Boolean paid = null;
  private String timeOffRequestId = null;
  private String externalActivityId = null;

  private static class ExternalActivityTypeEnumDeserializer extends StdDeserializer<ExternalActivityTypeEnum> {
    public ExternalActivityTypeEnumDeserializer() {
      super(ExternalActivityTypeEnumDeserializer.class);
    }

    @Override
    public ExternalActivityTypeEnum deserialize(JsonParser jsonParser, DeserializationContext ctxt)
            throws IOException {
      JsonNode node = jsonParser.getCodec().readTree(jsonParser);
      return ExternalActivityTypeEnum.fromString(node.toString().replace("\"", ""));
    }
  }
  /**
   * The type of the external activity associated with this activity, if applicable
   */
 @JsonDeserialize(using = ExternalActivityTypeEnumDeserializer.class)
  public enum ExternalActivityTypeEnum {
    OUTDATEDSDKVERSION("OutdatedSdkVersion"),
    COACHING("Coaching"),
    LEARNING("Learning");

    private String value;

    ExternalActivityTypeEnum(String value) {
      this.value = value;
    }

    @JsonCreator
    public static ExternalActivityTypeEnum fromString(String key) {
      if (key == null) return null;

      for (ExternalActivityTypeEnum value : ExternalActivityTypeEnum.values()) {
        if (key.equalsIgnoreCase(value.toString())) {
          return value;
        }
      }

      return ExternalActivityTypeEnum.values()[0];
    }

    @Override
    @JsonValue
    public String toString() {
      return String.valueOf(value);
    }
  }
  private ExternalActivityTypeEnum externalActivityType = null;

  
  /**
   * The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z
   **/
  public BuAgentScheduleActivity startDate(Date startDate) {
    this.startDate = startDate;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z")
  @JsonProperty("startDate")
  public Date getStartDate() {
    return startDate;
  }
  public void setStartDate(Date startDate) {
    this.startDate = startDate;
  }


  /**
   * The length of this activity in minutes
   **/
  public BuAgentScheduleActivity lengthMinutes(Integer lengthMinutes) {
    this.lengthMinutes = lengthMinutes;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The length of this activity in minutes")
  @JsonProperty("lengthMinutes")
  public Integer getLengthMinutes() {
    return lengthMinutes;
  }
  public void setLengthMinutes(Integer lengthMinutes) {
    this.lengthMinutes = lengthMinutes;
  }


  /**
   * The description of this activity
   **/
  public BuAgentScheduleActivity description(String description) {
    this.description = description;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The description of this activity")
  @JsonProperty("description")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }


  /**
   * The ID of the activity code associated with this activity
   **/
  public BuAgentScheduleActivity activityCodeId(String activityCodeId) {
    this.activityCodeId = activityCodeId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the activity code associated with this activity")
  @JsonProperty("activityCodeId")
  public String getActivityCodeId() {
    return activityCodeId;
  }
  public void setActivityCodeId(String activityCodeId) {
    this.activityCodeId = activityCodeId;
  }


  /**
   * Whether this activity is paid
   **/
  public BuAgentScheduleActivity paid(Boolean paid) {
    this.paid = paid;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "Whether this activity is paid")
  @JsonProperty("paid")
  public Boolean getPaid() {
    return paid;
  }
  public void setPaid(Boolean paid) {
    this.paid = paid;
  }


  /**
   * The ID of the time off request associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity timeOffRequestId(String timeOffRequestId) {
    this.timeOffRequestId = timeOffRequestId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the time off request associated with this activity, if applicable")
  @JsonProperty("timeOffRequestId")
  public String getTimeOffRequestId() {
    return timeOffRequestId;
  }
  public void setTimeOffRequestId(String timeOffRequestId) {
    this.timeOffRequestId = timeOffRequestId;
  }


  /**
   * The ID of the external activity associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity externalActivityId(String externalActivityId) {
    this.externalActivityId = externalActivityId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the external activity associated with this activity, if applicable")
  @JsonProperty("externalActivityId")
  public String getExternalActivityId() {
    return externalActivityId;
  }
  public void setExternalActivityId(String externalActivityId) {
    this.externalActivityId = externalActivityId;
  }


  /**
   * The type of the external activity associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity externalActivityType(ExternalActivityTypeEnum externalActivityType) {
    this.externalActivityType = externalActivityType;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The type of the external activity associated with this activity, if applicable")
  @JsonProperty("externalActivityType")
  public ExternalActivityTypeEnum getExternalActivityType() {
    return externalActivityType;
  }
  public void setExternalActivityType(ExternalActivityTypeEnum externalActivityType) {
    this.externalActivityType = externalActivityType;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BuAgentScheduleActivity buAgentScheduleActivity = (BuAgentScheduleActivity) o;

    return Objects.equals(this.startDate, buAgentScheduleActivity.startDate) &&
            Objects.equals(this.lengthMinutes, buAgentScheduleActivity.lengthMinutes) &&
            Objects.equals(this.description, buAgentScheduleActivity.description) &&
            Objects.equals(this.activityCodeId, buAgentScheduleActivity.activityCodeId) &&
            Objects.equals(this.paid, buAgentScheduleActivity.paid) &&
            Objects.equals(this.timeOffRequestId, buAgentScheduleActivity.timeOffRequestId) &&
            Objects.equals(this.externalActivityId, buAgentScheduleActivity.externalActivityId) &&
            Objects.equals(this.externalActivityType, buAgentScheduleActivity.externalActivityType);
  }

  @Override
  public int hashCode() {
    return Objects.hash(startDate, lengthMinutes, description, activityCodeId, paid, timeOffRequestId, externalActivityId, externalActivityType);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BuAgentScheduleActivity {\n");
    
    sb.append("    startDate: ").append(toIndentedString(startDate)).append("\n");
    sb.append("    lengthMinutes: ").append(toIndentedString(lengthMinutes)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    activityCodeId: ").append(toIndentedString(activityCodeId)).append("\n");
    sb.append("    paid: ").append(toIndentedString(paid)).append("\n");
    sb.append("    timeOffRequestId: ").append(toIndentedString(timeOffRequestId)).append("\n");
    sb.append("    externalActivityId: ").append(toIndentedString(externalActivityId)).append("\n");
    sb.append("    externalActivityType: ").append(toIndentedString(externalActivityType)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> platform-client-v2-203.0.0-sources.jar: com/mypurecloud/sdk/v2/model/BuAgentScheduleActivity.java <==
package com.mypurecloud.sdk.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.deser.std.StdDeserializer;
import java.util.Objects;
import java.util.ArrayList;
import java.io.IOException;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.Date;

import java.io.Serializable;
/**
 * BuAgentScheduleActivity
 */

public class BuAgentScheduleActivity  implements Serializable {
  
  private Date startDate = null;
  private Integer lengthMinutes = null;
  private String description = null;
  private String activityCodeId = null;
  private Boolean paid = null;
  private Integer payableMinutes = null;
  private String timeOffRequestId = null;
  private Integer timeOffRequestSyncVersion = null;
  private String externalActivityId = null;

  private static class ExternalActivityTypeEnumDeserializer extends StdDeserializer<ExternalActivityTypeEnum> {
    public ExternalActivityTypeEnumDeserializer() {
      super(ExternalActivityTypeEnumDeserializer.class);
    }

    @Override
    public ExternalActivityTypeEnum deserialize(JsonParser jsonParser, DeserializationContext ctxt)
            throws IOException {
      JsonNode node = jsonParser.getCodec().readTree(jsonParser);
      return ExternalActivityTypeEnum.fromString(node.toString().replace("\"", ""));
    }
  }
  /**
   * The type of the external activity associated with this activity, if applicable
   */
 @JsonDeserialize(using = ExternalActivityTypeEnumDeserializer.class)
  public enum ExternalActivityTypeEnum {
    OUTDATEDSDKVERSION("OutdatedSdkVersion"),
    ACTIVITYPLAN("ActivityPlan"),
    COACHING("Coaching"),
    LEARNING("Learning");

    private String value;

    ExternalActivityTypeEnum(String value) {
      this.value = value;
    }

    @JsonCreator
    public static ExternalActivityTypeEnum fromString(String key) {
      if (key == null) return null;

      for (ExternalActivityTypeEnum value : ExternalActivityTypeEnum.values()) {
        if (key.equalsIgnoreCase(value.toString())) {
          return value;
        }
      }

      return ExternalActivityTypeEnum.values()[0];
    }

    @Override
    @JsonValue
    public String toString() {
      return String.valueOf(value);
    }
  }
  private ExternalActivityTypeEnum externalActivityType = null;

  
  /**
   * The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z
   **/
  public BuAgentScheduleActivity startDate(Date startDate) {
    this.startDate = startDate;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z")
  @JsonProperty("startDate")
  public Date getStartDate() {
    return startDate;
  }
  public void setStartDate(Date startDate) {
    this.startDate = startDate;
  }


  /**
   * The length of this activity in minutes
   **/
  public BuAgentScheduleActivity lengthMinutes(Integer lengthMinutes) {
    this.lengthMinutes = lengthMinutes;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The length of this activity in minutes")
  @JsonProperty("lengthMinutes")
  public Integer getLengthMinutes() {
    return lengthMinutes;
  }
  public void setLengthMinutes(Integer lengthMinutes) {
    this.lengthMinutes = lengthMinutes;
  }


  /**
   * The description of this activity
   **/
  public BuAgentScheduleActivity description(String description) {
    this.description = description;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The description of this activity")
  @JsonProperty("description")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }


  /**
   * The ID of the activity code associated with this activity
   **/
  public BuAgentScheduleActivity activityCodeId(String activityCodeId) {
    this.activityCodeId = activityCodeId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the activity code associated with this activity")
  @JsonProperty("activityCodeId")
  public String getActivityCodeId() {
    return activityCodeId;
  }
  public void setActivityCodeId(String activityCodeId) {
    this.activityCodeId = activityCodeId;
  }


  /**
   * Whether this activity is paid
   **/
  public BuAgentScheduleActivity paid(Boolean paid) {
    this.paid = paid;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "Whether this activity is paid")
  @JsonProperty("paid")
  public Boolean getPaid() {
    return paid;
  }
  public void setPaid(Boolean paid) {
    this.paid = paid;
  }


  /**
   * Payable minutes for this activity
   **/
  public BuAgentScheduleActivity payableMinutes(Integer payableMinutes) {
    this.payableMinutes = payableMinutes;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "Payable minutes for this activity")
  @JsonProperty("payableMinutes")
  public Integer getPayableMinutes() {
    return payableMinutes;
  }
  public void setPayableMinutes(Integer payableMinutes) {
    this.payableMinutes = payableMinutes;
  }


  /**
   * The ID of the time off request associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity timeOffRequestId(String timeOffRequestId) {
    this.timeOffRequestId = timeOffRequestId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the time off request associated with this activity, if applicable")
  @JsonProperty("timeOffRequestId")
  public String getTimeOffRequestId() {
    return timeOffRequestId;
  }
  public void setTimeOffRequestId(String timeOffRequestId) {
    this.timeOffRequestId = timeOffRequestId;
  }


  /**
   * The sync version of the partial day time off request for which the scheduled activity is associated, if applicable
   **/
  public BuAgentScheduleActivity timeOffRequestSyncVersion(Integer timeOffRequestSyncVersion) {
    this.timeOffRequestSyncVersion = timeOffRequestSyncVersion;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The sync version of the partial day time off request for which the scheduled activity is associated, if applicable")
  @JsonProperty("timeOffRequestSyncVersion")
  public Integer getTimeOffRequestSyncVersion() {
    return timeOffRequestSyncVersion;
  }
  public void setTimeOffRequestSyncVersion(Integer timeOffRequestSyncVersion) {
    this.timeOffRequestSyncVersion = timeOffRequestSyncVersion;
  }


  /**
   * The ID of the external activity associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity externalActivityId(String externalActivityId) {
    this.externalActivityId = externalActivityId;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The ID of the external activity associated with this activity, if applicable")
  @JsonProperty("externalActivityId")
  public String getExternalActivityId() {
    return externalActivityId;
  }
  public void setExternalActivityId(String externalActivityId) {
    this.externalActivityId = externalActivityId;
  }


  /**
   * The type of the external activity associated with this activity, if applicable
   **/
  public BuAgentScheduleActivity externalActivityType(ExternalActivityTypeEnum externalActivityType) {
    this.externalActivityType = externalActivityType;
    return this;
  }
  
  @ApiModelProperty(example = "null", value = "The type of the external activity associated with this activity, if applicable")
  @JsonProperty("externalActivityType")
  public ExternalActivityTypeEnum getExternalActivityType() {
    return externalActivityType;
  }
  public void setExternalActivityType(ExternalActivityTypeEnum externalActivityType) {
    this.externalActivityType = externalActivityType;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BuAgentScheduleActivity buAgentScheduleActivity = (BuAgentScheduleActivity) o;

    return Objects.equals(this.startDate, buAgentScheduleActivity.startDate) &&
            Objects.equals(this.lengthMinutes, buAgentScheduleActivity.lengthMinutes) &&
            Objects.equals(this.description, buAgentScheduleActivity.description) &&
            Objects.equals(this.activityCodeId, buAgentScheduleActivity.activityCodeId) &&
            Objects.equals(this.paid, buAgentScheduleActivity.paid) &&
            Objects.equals(this.payableMinutes, buAgentScheduleActivity.payableMinutes) &&
            Objects.equals(this.timeOffRequestId, buAgentScheduleActivity.timeOffRequestId) &&
            Objects.equals(this.timeOffRequestSyncVersion, buAgentScheduleActivity.timeOffRequestSyncVersion) &&
            Objects.equals(this.externalActivityId, buAgentScheduleActivity.externalActivityId) &&
            Objects.equals(this.externalActivityType, buAgentScheduleActivity.externalActivityType);
  }

  @Override
  public int hashCode() {
    return Objects.hash(startDate, lengthMinutes, description, activityCodeId, paid, payableMinutes, timeOffRequestId, timeOffRequestSyncVersion, externalActivityId, externalActivityType);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BuAgentScheduleActivity {\n");
    
    sb.append("    startDate: ").append(toIndentedString(startDate)).append("\n");
    sb.append("    lengthMinutes: ").append(toIndentedString(lengthMinutes)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    activityCodeId: ").append(toIndentedString(activityCodeId)).append("\n");
    sb.append("    paid: ").append(toIndentedString(paid)).append("\n");
    sb.append("    payableMinutes: ").append(toIndentedString(payableMinutes)).append("\n");
    sb.append("    timeOffRequestId: ").append(toIndentedString(timeOffRequestId)).append("\n");
    sb.append("    timeOffRequestSyncVersion: ").append(toIndentedString(timeOffRequestSyncVersion)).append("\n");
    sb.append("    externalActivityId: ").append(toIndentedString(externalActivityId)).append("\n");
    sb.append("    externalActivityType: ").append(toIndentedString(externalActivityType)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
